# ✨🥞✨
[![Build](https://github.com/mortenengen/glowing-pancake/actions/workflows/build.yaml/badge.svg)](https://github.com/mortenengen/glowing-pancake/actions/workflows/build.yaml)
[![Package version](https://badge.fury.io/py/glopan.svg)](https://badge.fury.io/py/glopan)
[![codecov](https://codecov.io/gh/mortenengen/glowing-pancake/branch/main/graph/badge.svg?token=9JJ6J5HQ02)](https://codecov.io/gh/mortenengen/glowing-pancake)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](https://img.shields.io/badge/mypy-checked-blue)](http://mypy-lang.org/)
## 🤷‍♂️ What?
Glowing Pancake, glopan, is a simple Python package for converting figures and operating on pdfs.

## 📦 Installation
Glowing Pancake is pip-installable.
```
pip install glopan
```

## 🧙‍♀️ Usage
After a successful installation, Glowing Pancake can be imported as a regular python package

```
import glopan
```

or run from the command line by typing `glopan` or `python -m glopan`.

## 🪂 Dependencies
Glowing Pancake depends on the following third-party tools:
* [Inkscape](https://inkscape.org/) >= v.1.0.1, for converting from PDF to various graphics formats.
* [Ghostscript](https://www.ghostscript.com/) >= v.9.26, for converting from Postscript to PDF.
* Microsoft Word, for converting from DOCX to PDF.

## ❓ What's up with the silly package name?
Yup, the package is named after its Github repo, which got a random name when it was created...
